
# q-expansion of newform 1224.2.l.d, downloaded from the LMFDB on 12 February 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1224
weight = 2
poly_data = [512, 0, -128, 0, -64, 0, 16, -16, 8, 0, 4, -4, 2, 0, -2, 0, -1, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-128, 0, -64, 0, 16, -16, 8, 0, 4, -4, 2, 0, -2, 0, -1, 0, 1, 0], 128], [[-256, 0, -192, 96, -16, 16, -8, 8, 4, -4, 2, 4, -2, 4, -1, 0, 1, 0], 128], [[0, 384, 0, 0, 64, -48, 16, -24, 16, -12, 4, 6, 0, 6, 0, -3, 0, -1], 256], [[0, 128, 0, 64, 0, -16, 16, -8, 0, -4, 4, -2, 0, 2, 0, 1, 0, -1], 256], [[128, -64, 96, -48, 32, -24, 16, 12, -8, -2, 0, -2, 2, -3, 2, -1, 0, 0], 64], [[-256, 0, 128, -128, 144, -64, 48, -8, 12, 8, -8, 2, 2, -4, 4, -1, 2, -1], 128], [[256, 128, -512, 576, -416, 176, -128, -8, -8, -4, 8, 6, -4, 6, -10, 9, -6, 3], 256], [[768, -128, -256, 256, -384, 208, -64, 40, 16, 4, 8, -10, 0, 2, -6, 5, -6, 3], 256], [[1536, -128, -256, 384, -480, 240, -112, 72, -8, 12, 20, -10, 12, 2, -12, 5, -8, 3], 256], [[-384, 512, -64, 0, 64, -112, 24, 0, -8, 4, 2, 8, -8, 4, 1, -2, 1, -2], 128], [[-768, 256, 256, -256, 272, -160, 104, -40, -4, 0, -2, 10, -6, -2, 7, -5, 5, -3], 128], [[1280, -768, 384, -192, -16, 80, -72, 0, 4, 4, 10, -20, 14, -12, 3, -2, -3, 2], 128], [[-1280, 1920, -896, 768, -192, 16, 64, 24, 0, -12, -8, 26, -32, 26, -18, 7, -2, -3], 256], [[1792, -1664, 640, -384, -96, 176, -144, 56, 8, -4, 20, -22, 28, -22, 8, -1, -4, 5], 256], [[3328, -2176, 512, -128, -384, 400, -224, 88, 16, 20, 40, -46, 40, -22, -2, 3, -10, 9], 256], [[-3840, 2688, -512, 320, 512, -528, 288, -56, 16, 12, -24, 50, -48, 30, -2, -5, 14, -11], 256]]

hecke_ring_character_values = [[919, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [613, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [137, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [649, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 1, -1, 0, 1, 0, 1, -1, 1], [0, 0, 1, -1, 1, -1, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0], [0, 1, -1, 1, -1, -1, 0, 0, 0, 0, -1, 0, 0, 0, 0, -1, 1, 0], [0, 0, -1, -1, 0, 0, 0, -1, 0, 1, 0, -1, -1, 0, -1, 1, -1, 1], [0, 1, -1, 1, -1, 0, -1, 0, 0, 0, -1, 1, 0, 0, 1, 0, 0, 0], [-2, 0, -2, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, 0, 1, 0, 1, 0], [0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, -1, 0, 0, 0, 1, 0, 0], [0, -1, 1, -1, 0, 0, 1, 0, 1, 0, 0, -1, 0, 0, -1, 0, 1, 1], [0, 0, 0, 0, -1, 0, -1, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, -1], [0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, -1, 0, 1, 1, 1, -1, 0], [0, 1, -1, 1, -1, -1, -1, 1, 1, 0, -1, 2, 0, 0, 0, -1, 1, 0], [-2, 0, -2, 0, 1, 0, 1, -1, 0, -1, -1, 0, -1, 0, 0, 0, 1, 1], [0, -1, 1, -1, 1, -1, 1, 1, 1, 0, 1, 0, 0, 0, 0, -1, -1, 0], [0, 0, 0, 0, 0, -1, 0, 1, 1, 0, 2, 1, 0, 0, -1, -1, -1, 0], [0, 0, 0, 0, -1, 0, 0, 0, 1, 0, 1, 0, 0, 1, -1, -1, 0, 1], [0, 1, -1, 1, -1, 0, 0, -1, -1, 0, 1, -1, 0, 1, 1, 1, -2, 0], [0, 1, -1, 1, 0, -1, 0, 0, -1, 0, 0, 0, 0, -2, -1, -3, 1, -1], [0, 0, -3, -1, 0, -1, 0, -2, 1, 0, 0, -2, 0, 0, -1, 1, -1, 1], [0, 0, -2, 2, -1, 0, 1, 1, 0, 0, -1, 0, 0, 2, 1, -2, 0, -1], [0, -1, 3, -3, 1, -1, 1, -1, 1, 0, 3, -2, 0, 0, -2, 3, -1, 2], [-2, 0, -2, 0, 1, 0, 0, 0, 1, 0, 1, -2, 1, 1, 0, 1, -1, 1], [0, 0, 0, 0, -2, 0, -1, 1, -1, -2, 0, 2, 1, -1, 2, -1, 2, -2], [-2, 0, -2, 0, -2, -2, -1, -1, 1, 1, 0, 0, 1, -1, 1, -1, 1, -2], [0, 0, 0, 0, 0, -1, 0, 1, 1, 0, -2, 1, 0, 1, 2, 0, 0, 0], [-2, 0, -2, 0, -1, -2, 0, -2, 1, 0, -1, 0, -1, -1, 0, -1, 1, -1], [0, 0, -2, -2, -2, 0, -1, -1, -1, 2, 0, 0, 1, -1, 0, 1, 0, 0], [2, 1, 3, 1, 1, 2, 0, 1, 1, 0, 1, -1, 0, 1, -1, 0, -2, 0], [0, -1, -3, -1, -1, -2, -1, 0, 0, -2, 1, -1, 0, 0, 1, 1, 0, 0], [0, 2, 0, 0, 0, -1, -1, -2, -2, 0, 0, -1, 0, 1, 1, 3, -1, 0], [-2, -2, 1, -1, 0, -2, 0, 1, -2, 0, 0, 1, 0, 0, 0, 1, 0, 1], [0, 0, 0, 0, -2, 0, 0, 0, 2, 0, 2, 0, 0, 3, 0, 2, -2, 2], [0, 0, -4, 0, 2, 0, 1, -1, 1, -2, 0, -2, 0, 1, 0, 1, 0, 2], [0, 3, -1, 1, -1, -1, -3, -1, -1, 0, -3, 2, 0, -1, 2, 0, 1, 0], [-4, -2, 2, 2, 2, -4, 1, 1, 1, 1, 0, 0, 2, 1, 0, -1, 0, 0], [0, 0, -1, 1, 0, 0, 1, 0, -1, 0, -2, -1, 0, 1, 0, -2, 2, -1], [-2, -2, 0, -2, 1, -2, 0, 0, -1, 1, 1, -2, -1, 1, -2, 3, -3, 3], [0, 0, -2, -2, 1, 2, 1, -1, -2, 0, -1, 0, -2, 0, -1, 2, 0, 3], [0, 2, 0, 0, 2, -4, -1, 1, -1, 0, 0, 2, 0, -3, 0, -3, 0, -2], [-4, 0, 4, 0, -2, 0, 0, 0, -2, -1, -2, 4, 0, -2, 0, -2, 2, -2], [0, 0, -4, 4, -2, 0, 1, 3, 1, 0, -4, 2, 0, -1, 2, -4, 2, -2], [0, 2, -2, -2, -2, 4, -1, -1, -1, 2, 0, 0, 0, -1, 0, 1, 0, 0], [-2, 2, 2, 0, -1, 4, 0, 0, -1, 0, -1, 2, -3, -1, 0, -1, 1, -1], [0, 2, -4, 0, 2, 4, 2, -2, 0, -4, -2, 0, 1, 0, 0, 0, 2, 2], [0, 0, 2, -2, 2, -4, 0, 2, 2, 0, -2, 2, 0, -2, 0, 0, 2, 0], [0, 0, 2, -2, 2, -1, 1, -2, -2, 0, 2, -3, 0, 2, 0, 1, -2, 0], [-4, -2, 2, 2, 1, -4, 1, 1, 0, 0, -1, 2, 2, 0, 1, -2, 2, -1], [0, 2, 2, -2, 1, -4, 0, -2, -1, 0, -1, -2, 0, 3, 1, 3, 0, 1], [0, 0, 1, -1, 0, 0, -1, 0, 1, 0, -2, 1, 0, -1, 0, -2, 2, 1], [2, 1, 3, 1, -1, 2, 0, 1, -1, -4, -1, 3, 2, -1, 1, -2, 2, -2], [-4, 0, 4, 0, 0, 2, 0, 2, -2, 0, 0, 2, -2, 0, 0, 0, 0, 0], [0, -2, -4, 0, 0, -4, -1, 1, 1, 1, 2, -2, 0, 1, 2, 1, 0, 0], [-2, 2, 2, 0, -1, 4, 0, 0, -1, 0, -1, 2, 1, -1, 0, -1, 1, -1], [-2, 0, 0, 2, 3, 0, 0, 2, 3, 1, 3, -4, 1, 3, 0, 1, -3, 1], [0, 0, -3, -1, 0, 1, 0, 0, -1, -4, 0, 0, 0, 0, 1, 1, 1, 1], [0, 2, -2, -2, 0, 4, 1, -3, -1, 2, -2, 0, -2, -1, -2, 1, 0, 2], [0, 1, -1, 1, -3, 3, -1, -3, -1, 0, -1, -2, 0, 0, 2, 1, -1, 2], [0, 2, -3, 3, -4, 0, 0, -1, 0, 0, 0, -1, 0, 0, 0, -3, 0, 1], [0, -2, 4, -4, 4, -1, 1, 0, 0, 0, 4, -1, 0, -1, -3, 4, -1, 0], [0, -4, 4, -4, 3, 6, 0, -2, -1, 0, 1, -2, 0, -1, -1, 3, 0, 1], [-4, 0, 3, -1, 2, 4, 0, 3, -2, 1, 2, -1, -1, 2, -1, 3, -3, 3], [0, -3, 1, -1, 2, 6, -1, 0, -1, 0, 2, 1, 0, 0, -1, -4, -1, -1], [0, 0, 2, -2, 1, -4, 0, 2, 3, 0, 3, 2, 0, 1, -1, 3, -2, 1], [4, -4, 8, 0, 2, -4, 1, 3, -3, 2, 0, 2, -2, 1, -2, 1, -2, 2], [0, 2, 2, -2, 0, -4, 0, -2, 0, 0, 0, -2, 0, 1, 2, 2, -2, 2], [0, 1, -6, -2, -1, 1, 0, -3, 0, -4, -1, -1, 0, -1, 0, 1, 1, 1], [-4, -2, 2, 2, 0, -4, 0, 2, 0, -4, 0, 2, -2, 0, 2, -2, 2, -2], [0, 3, -3, 3, -5, 0, 0, -3, -1, 0, -3, -3, 0, -1, 1, -1, 2, 2], [0, -6, 4, -4, 4, 6, 2, 0, 0, 0, 4, -2, 0, -2, -4, 2, 0, 0], [0, -1, 1, 3, 1, -2, 1, 2, 0, 2, -1, 3, 2, 0, 3, -3, 4, -2], [0, 0, -6, 2, 1, -2, 1, -1, 2, -4, -1, 0, -2, 0, 3, -2, 4, -1], [0, -1, 1, -1, -1, 3, -1, -1, 1, 0, 5, 0, 0, 2, 0, 5, -5, 2], [-2, 4, 4, -2, -3, 8, -1, -1, -2, -1, -1, 2, 1, -2, -2, 0, -1, -1], [0, -4, 4, -4, 6, -1, 2, 3, 1, 0, 4, 1, 0, -3, -4, 0, 0, -2], [0, 0, -1, 1, 4, 1, 2, 0, 1, 4, 0, -2, 1, 2, -1, 1, -1, 3], [4, 0, 2, 2, -2, -4, -1, -1, 3, 2, 0, 0, 2, -1, 0, -3, 0, -4], [0, 0, 2, -2, 4, 2, -4, 0, -2, 0, -4, 4, 0, -3, 2, 2, 2, -2], [0, 4, 0, 0, -2, -7, 1, -2, 0, 0, 2, -3, 0, 1, -1, 2, -1, 2], [0, 2, 3, 1, 0, 5, 0, 2, -1, 0, 0, 2, -1, 0, 1, -1, 1, -1], [0, -3, -1, 1, 1, 6, -1, 2, 0, 0, 1, 3, 0, 0, -3, -2, 2, -2], [0, 0, -3, 3, -3, 4, -2, 1, 1, 0, -1, 3, 0, 1, 1, -6, 0, 0], [0, 3, -2, 2, -1, -7, 3, 0, -1, 0, 3, -3, 0, 2, -2, -6, -1, -1], [0, 2, 1, -1, -2, 3, 0, -2, -1, -4, -2, 2, 3, -2, -1, -1, 1, -1], [0, 1, -1, 1, 3, -1, -3, 3, -1, 0, -3, 6, 0, -2, 0, -3, 3, -4], [2, 2, -3, -1, 2, 4, 2, -3, 0, 0, -2, -1, 0, 0, -2, 1, 0, 3], [0, -4, 3, -3, 5, 0, 2, 3, 1, 0, 3, 1, 0, -1, -1, -4, -2, -2], [0, 3, -3, 3, -1, -7, 1, 3, 1, 0, -3, 2, 0, -3, 2, -2, 1, -2], [0, 1, 3, -3, 5, -8, 3, 0, -2, 0, 1, -3, 0, 0, -1, 2, 0, -2], [0, 0, 3, -3, 3, 0, -2, -1, -1, 0, 5, 1, 0, 3, -1, 6, -4, 0], [0, -3, 3, 1, -1, -6, 1, 0, -2, -2, -3, 5, 2, -2, 1, -3, 4, -2], [0, 1, -5, 5, -1, 3, -2, 2, -2, 0, -5, 4, 0, -2, 2, -7, 3, -4], [0, 1, -3, 3, -1, 3, -3, 1, -1, 0, -3, 4, 0, -2, 4, -1, -1, -2], [0, 4, -2, 2, -2, -7, -2, 3, 3, 0, -4, 5, 0, -5, 2, -2, 2, 0], [0, -1, 5, -5, 5, 1, -3, -1, -1, 0, 1, 2, 0, -4, 0, 3, -1, 0], [-2, 4, 8, 2, -2, 8, -1, 3, -1, 1, 0, 4, -1, -1, 1, -3, 1, -4], [4, -3, -5, -3, -1, -6, -2, -1, 1, 8, 3, -5, 0, 1, -1, 4, -4, 2], [0, -5, 3, -3, 3, 3, 3, 1, 1, 0, -3, -2, 0, -4, 0, -1, 3, 0], [0, -1, -3, 3, 1, 3, -1, 3, -1, 0, -3, 4, 0, 0, 0, 3, 3, -4], [-2, -1, 3, 1, -1, -2, 0, 1, -1, 0, -1, 3, 4, -1, 1, -2, 2, -2], [4, 1, -5, -3, 1, 2, 0, -3, 1, 4, 1, -5, -2, 1, -3, 4, -4, 4], [-2, -3, -1, 1, -1, -6, -1, 2, 0, -2, 1, 1, 1, 0, 3, -1, 2, -2], [0, -2, 3, -3, 0, 4, -1, -2, 1, 0, -2, -1, 0, -3, 2, 4, 0, 3], [-2, -1, 3, 1, -1, -2, -2, 3, 1, -4, 3, -1, 2, 1, 1, 0, -2, -2], [-4, 2, -6, 2, 1, 2, -1, 1, 4, 4, 3, -4, 6, 2, 3, 0, 0, -1], [0, 2, 0, 0, 2, -8, 1, 3, 1, 0, -4, 2, 0, -1, 0, -5, 4, -2], [0, 2, 2, -2, 2, -8, -1, 3, 3, 0, 4, 4, 0, -3, -2, -4, -2, 0], [0, 4, -6, 6, -4, -4, -2, 4, 2, 0, -4, 6, 0, -3, 0, -8, 4, -2], [0, 1, 0, 0, 1, 3, -3, -2, -3, 0, 1, 1, 0, -6, 0, 0, -1, -1], [4, 2, 2, -2, 0, 8, 0, 2, -4, -4, 0, 2, 0, 0, 0, 2, 0, 2], [2, 0, 2, 0, 1, 2, 0, 2, -1, -4, 1, 0, 5, 1, 0, 1, -1, 1], [0, 8, -2, 2, -2, -7, -3, -4, -4, 0, -6, -1, 0, -4, 4, 1, 2, 0], [0, -3, 3, 1, 1, -6, -1, 2, 2, 2, 3, -3, 0, 2, -1, 1, -4, 0], [12, -2, 6, -2, 1, -2, -1, 1, 0, 8, 3, -4, -6, 2, -5, 4, -8, 3], [12, 4, 6, 2, 2, 8, 0, 2, 2, -1, 2, -2, 0, 2, -2, 0, -4, 0], [0, -1, 1, -1, 2, 3, 0, -2, -3, 0, -2, -2, 0, 2, 3, 5, -1, -1], [0, -2, 0, 0, 4, 2, 0, 2, -2, 0, 4, 2, 0, 1, 0, 4, -4, -4], [0, -6, 8, -8, 5, 2, 3, -1, 2, 0, 9, -4, 0, 4, -5, 4, -4, 3], [-4, -2, -4, -4, -4, -4, -1, -3, -3, 1, -2, 2, 0, -3, 0, 1, 2, 0], [-8, 4, 4, 4, 0, 8, 0, 4, 0, -4, 0, 4, 1, 0, 4, -4, 4, -4], [4, 6, -2, 2, -2, 8, 0, -2, 2, -4, -2, 2, 4, -2, 2, -4, 4, -4], [0, -7, 7, -7, 5, 3, 3, 1, 3, 0, 7, -2, 0, 2, -6, 1, -1, 2], [-2, -4, 8, 2, 3, -6, 2, 2, -1, 1, -1, 2, 1, 1, -2, -1, -1, 1], [0, 1, 1, -1, -3, -3, 1, -1, 3, 0, 3, -2, 0, 3, 0, 4, -3, 4], [-14, -2, -5, -3, -2, -2, -2, 1, -2, -4, 2, -1, -4, 0, 2, 3, 0, 1], [0, 2, -2, 2, 0, 2, -4, 0, -2, 0, 0, 4, 0, 0, 0, -2, 0, -2], [0, -2, -3, 3, -1, 5, 0, 2, 0, 0, -5, 2, 0, 0, 3, 6, 2, -2], [0, -6, 6, -6, 4, 3, 1, 2, 4, 0, 0, 1, 0, -1, -3, -2, 3, 2], [0, -3, 3, -3, -1, 6, 2, -5, -1, 0, 1, -7, 0, -3, -1, 7, 0, 4], [0, 2, -4, 4, -4, -4, 2, 2, 2, 0, -4, 0, 0, 1, -2, -2, 6, 0], [2, 0, -6, -2, -2, 0, -2, 0, 0, 8, 2, -2, 0, 0, 2, 2, 0, 0], [2, -3, -7, -1, 3, -6, 1, -2, 2, -6, 1, -5, -1, 2, -1, 3, -2, 4], [0, 0, 4, -4, 2, -7, 1, 2, 4, 0, 2, 1, 0, 1, -3, -5, 1, 2], [4, -1, 1, -1, 1, -2, 2, -3, -1, -8, -3, 1, -6, -1, -3, 0, 0, 2], [0, -3, 7, -7, 9, -1, -1, 1, -1, 0, 3, 2, 0, -6, -6, -3, 3, -2], [0, 4, -6, 6, -4, -3, -2, 3, 1, 0, -2, 5, 0, 5, 4, 0, -2, -2], [0, 1, 7, -3, 3, 6, 1, 0, -2, 2, 1, -3, -6, 2, -7, 5, -8, 6], [12, 2, 0, 0, -2, 0, -1, -3, 3, 5, 0, -2, 2, -1, -2, -1, -2, -2], [0, 1, 3, -3, 1, -8, 3, 0, 2, 0, -3, -3, 0, -2, 3, 6, 0, 2], [-8, -4, -6, 2, 2, -12, 3, -5, 3, 2, -4, 0, 1, -1, 0, -3, 4, 0], [0, -2, 4, -4, 2, 2, 2, -4, -2, 0, 6, -6, 0, 4, -4, 4, -2, 2], [0, 3, 1, -1, 3, -7, 1, -1, -3, 0, 1, -2, 0, 1, 2, 2, -3, -2], [-14, 4, -8, -2, 2, 8, 1, -3, 1, 5, 0, -4, -3, 1, -1, 3, -1, 4], [0, 7, -2, 2, 1, -7, -5, 0, -3, 0, 1, 5, 0, -4, 0, 4, -1, -3], [0, 0, -3, 3, -4, 6, 0, -3, -2, 0, 0, -3, 0, 0, 2, 1, -2, 1], [-4, 4, -10, -6, -5, 4, -1, -9, 0, 4, -3, -2, -8, -4, -3, 2, 0, 1], [-14, 2, -6, -4, -5, 2, -2, -4, -1, 5, -1, 0, -5, -3, 0, 1, 1, -1], [0, -3, -2, 2, -5, 11, -2, -1, 2, 0, -3, 1, 0, -1, 2, 5, 1, 3], [0, 6, 1, -1, -1, -9, 0, -4, -2, 0, -1, -4, 0, 0, 3, 2, -2, 2], [0, 1, 1, -1, 3, -7, 0, 4, 2, 0, -5, 4, 0, -2, 0, -3, 5, -2], [4, -5, 1, -1, 1, -10, 0, -1, 1, 4, 1, -3, -6, 1, -3, 2, -4, 2], [0, 1, -1, 1, -1, -3, 2, 0, 0, 0, -1, -2, 0, 4, 0, -3, 1, 0], [-2, -6, 10, 0, 5, -8, 2, 2, -1, 8, 1, -2, -3, 3, -6, 3, -7, 5], [0, 0, 6, -6, 4, -7, 0, 1, 3, 0, 10, 1, 0, 3, -8, -2, -2, 2], [-4, -1, 0, 0, -3, -3, -1, 0, -1, -6, -1, 3, -4, -2, 2, -2, 3, -3], [12, -4, 1, -3, -4, -8, -4, 1, 0, 9, 4, -3, 3, 0, -1, 3, -5, -1], [4, -6, -2, 2, 6, -8, 2, 4, 0, 0, 2, -2, 0, 4, 2, 2, 0, 4], [-8, 1, -2, 2, 5, 3, 4, -1, 0, -12, -3, 1, -4, 1, 0, -1, 3, 3], [2, -2, 6, 0, -1, -4, -2, 2, 1, 0, 3, -2, -1, 1, -2, 1, -5, -1], [0, 3, -5, 5, -1, -3, -1, 3, -1, 0, -1, 4, 0, -2, 4, -9, -3, -4], [-6, 0, 6, 2, 2, 4, 0, 6, -2, -4, 2, 2, 2, 2, 2, 0, 0, 0], [0, -3, 3, -3, 3, -3, 6, 0, 0, 0, 3, -6, 0, 0, -4, -3, 1, 0], [0, 2, 2, -2, 2, -2, -2, -2, -2, 0, -2, 0, 0, 2, 4, 3, -2, 0], [-14, -6, -2, 0, 0, -10, -1, 3, -1, -3, 2, 0, 1, 1, 3, 1, 1, 0], [0, 4, -6, 6, -7, -4, 1, 1, 2, 0, -3, 0, 0, 0, 3, 4, 0, 1], [-12, 2, 1, 1, 0, 4, -1, 2, 1, 3, 2, -1, 5, 1, 1, 0, -1, -1], [0, 3, -1, 1, -2, -3, -2, 0, 1, 0, -2, 2, 0, 4, 1, -3, 1, 1], [0, 2, 0, 0, -2, -8, 2, 2, 4, 0, 2, 0, 0, -1, -2, -4, 0, 2], [0, -5, 1, -1, 3, 7, 1, 1, -1, 0, -3, 0, 0, -5, -4, -6, 7, -2], [8, 2, 1, -1, -6, 1, -2, -2, -1, -12, -2, 4, -3, -4, 1, -3, 3, -5], [2, 4, 10, 0, -7, 6, -4, 2, -1, 0, 1, 4, -3, -3, 0, -3, -1, -7], [0, 0, 2, -2, 2, -3, 3, -2, -2, 0, 2, -5, 0, 2, -4, 3, 2, 0], [4, -3, 7, 1, -3, -6, 0, 1, -3, -4, -3, 7, 2, -3, 1, -4, 4, -4], [-12, 4, 2, -2, -2, 8, 0, -2, -2, -5, -2, 2, -2, -2, -2, 0, 0, 0], [10, -4, -6, 0, 5, -8, 2, -2, 3, -4, 1, -6, -5, 3, -2, 3, -3, 5], [0, -2, 8, -8, 8, -6, 0, 2, 2, 0, 0, 2, 0, -3, 0, 4, 0, 0], [-14, 6, -6, -4, -1, 10, 0, -6, 1, 4, -1, -4, -3, -1, -4, 3, -3, 3], [-4, 4, 6, -2, -2, 8, 1, -3, -3, 2, -4, 4, -2, -3, -4, -1, 0, 0], [-14, 0, 0, -2, -3, 2, -1, 1, -4, -5, -1, 4, 7, -2, 2, 0, 3, -1], [2, 4, -14, -2, -2, 4, -2, -4, 4, 0, 2, -6, 0, 0, 2, 2, 0, 0], [-12, 0, 2, -2, -8, -2, -2, -2, -4, 0, -4, 8, 4, -6, 2, -4, 6, -6], [0, -1, -5, 5, -7, 5, 3, -1, 1, 0, -5, -4, 0, 4, 4, 5, 1, 2], [6, 0, 6, 0, -7, -2, -4, 2, -1, 1, 1, 4, -5, -3, 2, -3, 1, -7], [0, -11, 1, -1, 2, 12, 5, 4, 3, 0, 2, -1, 0, 4, -1, -6, -1, -1], [0, -2, -4, 4, -3, 12, -4, 0, -1, 0, -1, 4, 0, 5, 7, 5, -6, -1], [0, 0, 0, 0, -4, 1, 0, -1, 3, 0, 2, -1, 0, 8, 1, -1, -3, 4], [0, 4, -8, 8, -4, 2, -2, 0, -4, 0, -4, 2, 0, 0, 4, 2, 0, -4], [-4, -4, 4, 4, -4, -12, -2, 2, 2, 4, 0, 4, 4, -2, 4, -6, 4, -8], [0, 4, 1, -1, 1, -3, -4, -2, -2, 0, -3, 2, 0, -6, 3, 4, 0, 0], [0, 2, -6, 6, -4, 1, -3, 4, 2, 0, 0, 7, 0, 1, 3, -5, -3, -2], [-8, 4, -8, 0, -2, 4, 1, -5, 1, -2, -4, 2, -1, -3, 2, -3, 6, -2], [0, -3, -2, 2, -1, 11, -1, -2, -3, 0, 3, -1, 0, 2, 0, -2, -3, -1], [0, -10, 8, -8, 8, 8, 5, -1, -1, 0, 14, -6, 0, -3, -10, 5, -4, 0], [-14, 4, -2, 4, 4, 8, 2, 2, 2, 3, 0, 0, 7, 2, 3, -2, 3, 0], [0, -1, -4, 4, -7, 5, 0, 1, 4, 0, -1, 1, 0, 3, 4, -1, -3, 3], [-12, 0, 0, 4, 4, 2, 0, 6, 2, -8, 4, -2, 6, 4, 4, 0, 0, 0], [-12, 0, -2, 2, 4, 0, 2, 0, 2, -1, 0, -2, -6, 2, 0, 0, 0, 2], [0, 4, 0, 0, -4, -8, 2, -2, 2, 0, 8, -4, 0, 0, -4, 3, -4, 4], [0, 0, 4, -4, 6, -6, 2, 0, -2, 0, 2, -2, 0, -1, -2, -8, 0, -2], [-2, 3, 3, 1, -1, 2, -1, -2, 4, 6, 1, -3, 3, 0, -3, -1, -4, -2], [0, -7, 5, -5, 2, 1, 8, 0, 3, 0, 6, -8, 0, 8, -5, -3, -1, 3], [0, -2, 0, 0, 6, -3, 3, 4, -2, 0, 6, 1, 0, -3, -7, -7, 1, -6], [10, 8, 1, -1, -2, 16, 0, -1, -2, -4, -2, 3, 4, -2, 0, -1, 2, -1], [0, 8, -13, 13, -12, 6, -5, -4, -5, 0, -6, 1, 0, 7, 6, -8, 0, -1], [0, 0, -8, 8, -6, 5, 2, 1, -1, 0, -4, -1, 0, 3, 0, -12, 4, -2], [0, -2, 1, -1, 4, -2, 6, -1, -4, 0, 0, -7, 0, -2, 0, 7, 0, -3], [0, 0, -4, 4, -3, 2, 2, 0, -1, 0, 3, -2, 0, -1, 1, -1, -4, -1], [0, -4, 6, -6, 2, 1, 5, -4, 0, 0, 6, -9, 0, -1, -3, 1, -3, 4], [0, 3, -3, 3, -1, -2, -2, 1, -1, 0, 1, 3, 0, -1, -1, -3, 0, -2], [0, -6, 1, -1, 1, 2, 6, 3, 3, 0, -5, -3, 0, 3, 1, 6, 4, 0], [0, -5, 3, -3, 3, 1, 5, 1, 1, 0, 5, -4, 0, 1, 0, 8, -5, 0], [0, -6, 10, -10, 6, 4, -2, 0, 4, 0, 6, 2, 0, 0, -2, 6, -4, 4], [10, -6, -2, 0, 1, -14, 2, -4, 1, -4, -3, 0, -3, -1, -2, -1, 1, 1], [10, -1, 9, 3, 5, 2, 2, 5, -1, 8, 1, 1, -4, 3, -1, 0, -2, 2], [0, -11, 3, -3, 5, 11, 5, 3, 1, 0, 3, -2, 0, 1, 0, -2, -3, -2], [0, 2, -2, 2, -8, 5, -3, -4, 2, 0, -4, -1, 0, 7, 3, 3, 1, 6], [0, -4, 0, 0, -4, 12, 0, -4, 0, 0, -4, -4, 0, 1, 0, 8, 4, 4], [0, -5, 1, -1, 7, 4, 2, 3, -3, 0, 5, 1, 0, -3, -7, -11, 2, -6], [8, 3, 4, -4, -3, 7, 0, -3, -4, -8, -3, 3, -10, -3, -4, 1, -1, 1], [0, 4, 0, 0, -4, -2, -1, -5, -1, 0, -2, -4, 0, 11, 2, 8, 0, 4], [0, 0, 9, -9, 9, -6, -2, -1, -1, 0, -1, 1, 0, -9, -3, 10, 4, 0], [0, 2, 6, -6, 4, -16, 6, 0, 2, 0, 4, -6, 0, 6, 2, 8, -6, 2], [0, -8, 0, 0, 0, 5, 7, 4, 4, 0, 0, -3, 0, 0, 0, -5, 0, 0], [0, 3, -7, 7, -5, 5, -1, -3, -5, 0, -3, -2, 0, 3, 4, 4, -1, -2], [6, 0, 10, 4, -3, 0, -4, 8, 1, 8, 5, 2, 5, 1, 4, -3, -1, -7], [-4, 6, 0, -4, -2, 12, 0, -4, -2, 4, -2, 0, -4, -2, -4, 2, -2, 2], [0, 6, -10, 10, -4, -2, -2, 2, -4, 0, -4, 4, 0, 3, 4, -8, 0, -6], [-8, 0, -8, -4, -4, -4, 1, -9, -1, 2, -6, 2, -6, -5, -2, -1, 4, 0], [-10, 0, -9, 1, -4, -8, -2, -5, 6, 8, 0, -3, 4, -2, 2, -3, 2, -5], [0, -3, 10, 6, 1, -7, 2, 3, 0, 4, -3, 7, 10, -1, 2, -7, 5, -5], [0, 7, -3, 3, -5, -13, -1, 3, 5, 0, -5, 4, 0, 0, -2, -13, 7, 2], [24, -2, 8, 4, 2, -6, 0, 2, 4, 4, 2, -2, -2, 2, -2, -2, -4, -2], [0, -2, -2, 2, -1, 8, -1, -1, -2, 0, -9, 0, 0, -2, 11, 8, -2, -1], [-16, -2, -2, 2, 4, -4, 1, 1, 3, -3, 2, -4, 2, 3, 0, 1, -2, 2], [8, 2, 0, -4, 2, 8, 0, 0, -2, -4, 2, -4, 1, 2, -4, 6, -6, 6], [12, -4, -6, -2, 1, -6, -1, 1, 0, 0, 3, -4, 0, 2, 1, 4, -2, 3], [8, -4, 0, 0, 4, -4, 0, 4, 0, 4, 4, -4, -1, 4, 0, 4, -4, 4], [0, -2, -7, 7, -6, 12, -2, 1, 0, 0, -2, 3, 0, 0, 2, 5, 0, -1], [-14, -4, 6, -4, 3, -2, 2, 0, -5, 4, -1, 0, -7, 1, -6, 5, -5, 7], [0, -6, 8, -8, 10, 0, 2, 2, 0, 0, 6, 0, 0, -1, -6, 0, 0, -2], [0, -4, 4, -4, 6, 7, -6, 3, 1, 0, -4, 9, 0, -3, 0, 4, 4, -2], [0, 1, -1, 1, -3, 5, -3, -3, -1, 0, -1, 0, 0, -5, 2, 10, -1, 2], [0, 2, -2, 2, -6, -2, -1, 1, 5, 0, 0, 2, 0, 11, 0, -8, 0, 4], [8, -2, 0, -4, -4, -4, -1, -3, -3, -2, -2, 2, -7, -3, -2, 1, 0, 0], [0, -1, -3, 3, 2, 4, -1, 2, -3, 0, 2, 3, 0, 6, 1, -4, -3, -5], [0, 4, 8, 0, -3, 6, -1, -1, 0, 0, -1, 2, 4, -2, -3, -2, -2, -3], [0, -4, -2, 2, -2, 8, 2, 0, 0, 0, -6, -2, 0, 3, 4, -6, 2, 0], [0, -5, 10, -10, 5, 1, 1, -2, 3, 0, 9, -3, 0, -6, -12, 6, 3, 5], [8, -4, -6, -6, 5, -4, 3, -5, -2, 12, -1, -6, -2, 2, -7, 8, -6, 11], [0, -2, 6, -6, -2, -2, 4, -4, 4, 0, 6, -8, 0, 8, -2, 12, -4, 8], [0, 6, -2, 2, -2, -9, -3, 2, 2, 0, -6, 5, 0, 1, 3, -7, 3, 0], [0, 0, 3, -3, 1, -8, 4, 1, 3, 0, -5, -3, 0, -1, 1, -6, 4, 2], [14, 6, 2, 0, 2, 14, 1, 1, -1, 1, 0, 0, -9, 1, -1, 1, -1, 2], [-4, 5, -9, 1, -9, 2, -4, -3, 3, -8, -1, 3, 4, -5, 7, -6, 8, -10], [12, -2, -6, 2, 0, -4, 1, 1, -1, -7, -2, 4, 4, -1, 6, -3, 8, -2], [-2, 0, 0, 4, 2, 0, 0, 4, 2, -8, 2, 0, -4, 2, 4, -2, 2, -2], [0, 3, -3, 3, -3, -2, 1, -2, -2, 0, 1, -3, 0, -6, -3, 2, 2, 0], [0, 3, -1, 1, -3, -5, -1, 1, 3, 0, 5, 2, 0, 4, 4, 9, -9, 2], [-14, 4, 10, 0, 0, 10, 0, 2, -2, -9, 0, 2, -9, 0, -3, 0, -3, 0], [-14, -4, 12, 2, 0, -4, -1, 7, -3, -7, 2, 4, -3, 1, 1, -1, -1, -2], [0, 4, -4, 4, 2, 1, -4, -1, -7, 0, 0, 3, 0, 1, 0, 6, 0, -6], [0, 4, -7, 7, -3, -3, 0, 2, -2, 0, 1, 2, 0, -8, -5, -12, 4, -4], [0, 8, 0, 0, -4, -5, -3, -8, -4, 0, 4, -5, 0, -5, -3, 1, -1, 4], [8, 0, -3, -1, 0, 1, -2, 2, 1, -8, 4, -4, 2, 2, 1, 3, -3, 1], [-8, -3, -5, 1, 3, -6, 1, 0, 2, 10, 1, -3, 6, 2, 1, 1, 0, 2], [0, -9, 11, -11, 11, 7, -1, 1, 1, 0, 5, 2, 0, 2, 0, 7, -5, 0], [-14, -4, 4, -6, 4, -2, 1, -1, -3, 17, 2, -6, 1, 3, -9, 9, -11, 10], [0, -3, 9, -9, 2, 4, 1, -8, -1, 0, 10, -9, 0, 4, -1, 14, -9, 7], [2, -3, 9, -1, 3, -2, -1, 4, 0, -2, 5, -5, 5, 4, -5, 5, -10, 4], [-10, 2, 1, -1, -2, 2, 2, -5, -2, 4, -6, 5, -4, -4, -2, -3, 4, -1], [-12, 3, -12, -4, 1, 7, 1, -4, -1, -6, -1, -3, 0, 0, 0, 4, 1, 5], [-2, -2, -10, -4, 1, -2, 0, -2, -1, 0, 1, -4, 3, 1, 0, 5, -1, 5], [0, -1, 1, -1, 2, -5, 4, 2, 1, 0, 6, -2, 0, -8, -7, -7, 1, -1], [0, -6, 2, -2, 2, 14, -2, -2, -2, 0, -2, 0, 0, -3, 0, 6, 2, 0], [-4, 0, -3, 3, -4, -3, 0, 0, -1, -8, -4, 8, 1, -4, 7, -7, 11, -7], [0, -7, 9, -9, 6, 11, -2, -4, -1, 0, 10, -2, 0, 6, -7, 3, -3, 3], [12, 4, -10, -6, -6, 8, -2, -4, -4, 4, -2, 2, 4, -4, 2, 2, 4, 0], [0, -8, 16, -16, 12, -4, 2, 2, 6, 0, 8, 0, 0, -4, -8, 7, 0, 4], [0, 0, 2, -2, -2, 5, -5, -2, 2, 0, 2, 3, 0, 3, -1, 2, -1, 4], [0, 2, 4, -4, 0, -6, 2, -4, 0, 0, 8, -6, 0, 2, 0, 18, -8, 4], [-4, -1, -11, 3, 5, -6, 2, -3, 7, 0, 1, -7, 2, 3, 1, 0, 0, 2], [-4, 0, 12, 8, -3, -4, -1, 5, 2, 4, -1, 8, 2, -2, 5, -10, 6, -11], [0, 4, 2, -2, 6, -14, -3, 7, 3, 0, -4, 10, 0, -11, -4, -11, 8, -4], [-20, 2, 1, -7, -2, 8, -1, -2, -5, 7, 0, -1, -3, -1, -5, 6, -5, 5], [18, -8, -2, -4, -1, -12, -4, 4, -1, 16, 7, -6, -1, 3, 0, 7, -7, 3], [16, -3, 18, -2, 1, -1, 0, 3, -4, -4, 1, 1, -4, 1, -8, 3, -9, 3], [24, -2, 0, -4, 2, -4, 3, -7, -1, 5, -4, -2, -4, -1, -8, 3, -4, 6], [8, -2, -6, -2, 4, 0, 1, 1, -1, 6, 2, -4, -3, 3, 0, 5, -2, 6], [-10, -1, -9, -3, 9, 2, 6, -5, -1, -8, -3, -5, 0, 3, -5, 6, -2, 12], [8, 2, -8, -4, 0, 4, 3, -7, -3, 2, -6, 2, -3, -3, -2, 1, 4, 4], [2, -4, -8, -2, 4, -2, -1, 5, -1, -3, 6, -6, -7, 5, 3, 7, -3, 6], [-20, 4, -2, 2, -2, 4, 2, -4, 0, 3, -6, 6, -2, -4, 2, -6, 8, -4], [22, 2, -3, 3, -4, 2, 0, 1, -2, -8, -4, 9, 4, -4, 8, -7, 12, -7], [0, -2, -4, 4, 0, -1, 7, 2, -2, 0, -8, -5, 0, -3, 1, 3, 7, -4], [8, 0, -10, -10, -4, 0, -2, -8, -2, 4, 0, -6, -7, -2, -6, 8, -6, 6], [0, -6, -3, 3, 2, 4, 6, 5, 0, 0, -2, -1, 0, 0, -2, 1, 4, -5], [-4, -6, -5, -3, -2, -13, 2, -6, -3, 8, -6, 4, -1, -4, -1, -1, 5, 1], [0, 4, 0, 0, 0, -15, 3, 4, 4, 0, 0, 1, 0, 5, -1, -1, 1, 0], [0, 1, 7, -7, 3, -10, 3, -2, 2, 0, 7, -5, 0, -4, -5, 0, -2, 4]]
